// ConfirmUnsavedDocumentDlg.h
// (c) 2003-2005 exeal

#ifndef _CONFIRM_UNSAVED_DOCUMENT_DLG_H_
#define _CONFIRM_UNSAVED_DOCUMENT_DLG_H_
#include "../Manah/Dialog.h"
#include "../Manah/LinkLabel.h"
#include <vector>


namespace Alpha {
	///	ۑ̃t@C
	struct TDirtyFile {
		unsigned int	index;			///< ԍ (_CAONX͎gpȂ)
		std::wstring	strFileName;	///< t@C
		bool			bSave;			///< ۑ邩ǂ
	};

	///	[ۑĂȂhLg] _CAO
	class CConfirmUnsavedDocumentDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_CONFIRMUNSAVEDDOCUMENTS> {
		// bZ[Wnh
	protected:
		bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);
		bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);
		void	OnOK();

		// f[^o
	public:
		std::vector<TDirtyFile>					m_files;
		Manah::Windows::Controls::CLinkLabel	m_selectAllLink;
		Manah::Windows::Controls::CLinkLabel	m_clearAllLink;
	};
}

#endif /* _CONFIRM_UNSAVED_DOCUMENT_DLG_H_ */

/* [EOF] */